==> general_lib-0.0.28.tar.gz: example/lib/scheme/docker_plugin.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names, unused_import
import "package:general_lib/general_lib.dart";
// import "dart:convert";



class DockerPlugin extends JsonScheme {

  
  DockerPlugin(super.rawData);
   
  static Map get defaultData {
    return {"@type":"DockerPlugin","name":"","script":""};
  }

  
  String? get special_type {
    try {
      if (rawData["@type"] is String == false){
        return null;
      }
      return rawData["@type"] as String;
    } catch (e) {
      return null;
    }
  }


  
  String? get name {
    try {
      if (rawData["name"] is String == false){
        return null;
      }
      return rawData["name"] as String;
    } catch (e) {
      return null;
    }
  }


  
  String? get script {
    try {
      if (rawData["script"] is String == false){
        return null;
      }
      return rawData["script"] as String;
    } catch (e) {
      return null;
    }
  }


  
  static DockerPlugin create({

    String special_type = "DockerPlugin",
    String? name,
    String? script,
})  {
    // DockerPlugin dockerPlugin = DockerPlugin({
Map dockerPlugin_data_create_json = {
  
      "@type": special_type,
      "name": name,
      "script": script,


};


          dockerPlugin_data_create_json.removeWhere((key, value) => value == null);
DockerPlugin dockerPlugin_data_create = DockerPlugin(dockerPlugin_data_create_json);

return dockerPlugin_data_create;



      }
}

==> general_lib-0.0.30.tar.gz: example/lib/scheme/docker_plugin.dart <==
/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names, unused_import
import "package:general_lib/general_lib.dart";
// import "dart:convert";

class DockerPlugin extends JsonScheme {
  DockerPlugin(super.rawData);

  static Map get defaultData {
    return {"@type": "DockerPlugin", "name": "", "script": ""};
  }

  String? get special_type {
    try {
      if (rawData["@type"] is String == false) {
        return null;
      }
      return rawData["@type"] as String;
    } catch (e) {
      return null;
    }
  }

  String? get name {
    try {
      if (rawData["name"] is String == false) {
        return null;
      }
      return rawData["name"] as String;
    } catch (e) {
      return null;
    }
  }

  String? get script {
    try {
      if (rawData["script"] is String == false) {
        return null;
      }
      return rawData["script"] as String;
    } catch (e) {
      return null;
    }
  }

  static DockerPlugin create({
    String special_type = "DockerPlugin",
    String? name,
    String? script,
  }) {
    // DockerPlugin dockerPlugin = DockerPlugin({
    Map dockerPlugin_data_create_json = {
      "@type": special_type,
      "name": name,
      "script": script,
    };

    dockerPlugin_data_create_json.removeWhere((key, value) => value == null);
    DockerPlugin dockerPlugin_data_create =
        DockerPlugin(dockerPlugin_data_create_json);

    return dockerPlugin_data_create;
  }
}
